@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2016-10-26'; # DATE
-our $VERSION = '1.62'; # VERSION
+our $DATE = '2016-10-27'; # DATE
+our $VERSION = '1.63'; # VERSION
 
 use 5.010001;
 use strict;
@@ -28,6 +28,7 @@ has get_subcommand_from_arg => (is=>'rw', default=>1);
 has description => (is=>'rw');
 has exit => (is=>'rw', default=>1);
 has formats => (is=>'rw');
+has default_format => (is=>'rw');
 has pass_cmdline_object => (is=>'rw', default=>0);
 has per_arg_json => (is=>'rw');
 has per_arg_yaml => (is=>'rw');
@@ -1298,6 +1299,8 @@ sub run {
         $r->{format} = 'json';
     }
 
+    $r->{format} //= $self->default_format;
+
     if ($self->read_config) {
         # note that we will be reading config file
         $r->{read_config} = 1;
@@ -1447,7 +1450,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.62 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-10-26.
+This document describes version 1.63 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-10-27.
 
 =head1 DESCRIPTION
 
@@ -2038,6 +2041,10 @@ command-line argument even though there is C<default_subcommand> defined).
 
 Available output formats.
 
+=head2 default_format => str
+
+Default format.
+
 =head2 pass_cmdline_object => bool (default: 0)
 
 Whether to pass special argument C<-cmdline> containing the cmdline object to
